clear
clear matrix
set more off
capture log close
version 13.1

global data D:\...\replication_files
log using $data\going_back_home.log, replace text


/* 
THIS DO FILE REPLICATES THE MAIN RESULS (FIGURE 2 AND TABLES 6 & 7) IN 
Hirvonen & Liller (2015, World Development) "Going Back Home: Internal Return Migration in Rural Tanzania" 
*/

*ORDER: 
	*Table-6
	*Figure-2
	*Table-7


use $data\going_back_home.dta, clear
isid PID //=unique identifier
count

desc rmigrant
label list rmigrant

*cotrols for Table-6 (measured in 1991/4):
global CHAR91 male years91 child hhsize_91 head_sex_91  fgrade_91 mgrade_91 landowned_91  ///
schooldmean91 urban91 lnconspc91   d91_1 d91_3 d91_4 d91_5 d91_6

*cotrols for Table-7 (mostly measured in 2004)::
global CONTROLS    years04 miglength04   primary04 secondary04 ///
uempl04    farmw04  casual04 parent  married04 divwid04 ///
nathomeYN landowned04 lnconspc04  lnconspc04_sq  conspc04mis hhsize  child  loc_2 loc_3 loc_4 ///
inhlandYN shock0409  BLshock0409   getsmarr unmarries ///
d91_1 d91_3 d91_4 d91_5 d91_6   




********************************************************************************************************************************************************
*Table 6: estimating selection into migration (column 1) and into return migration (column 2) using characteristics at the baseline (1991-94)
********************************************************************************************************************************************************

gen lnconspc91_sq=lnconspc91^2
label var lnconspc91_sq "squared: logged 1991 consumption per capita"


sum $CHAR91

*COLUMN-1: SELECTION INTO MIGRATION
	*coeff:
	probit moved1 $CHAR91  , robust
 	fitstat
	*Mfx:
	estpost margins, dydx(*)
 
*COLUMN-2: SELECTION INTO RETURN MIGRATION
preserve
	*drop stayers from this model:
	drop if rmigrant<0
	tab rmigrant,m
	sum $CHAR91
	*coeff:
	probit rmigrant $CHAR91, robust
 	fitstat
	*Mfx:
	estpost margins, dydx(*)
restore
 
*additional models:
 
*Re-estimate column 2 using a multinomial probability model: 
 
	label list rmigrant
	mprobit rmigrant $CHAR91  , robust base(0)  
   

	*Check asset accumulation story:

	sum lndvalpc91

	*replace the consumption variable with 1991-asset variable:
	global CHAR91A male years91 child hhsize_91 head_sex_91  fgrade_91 mgrade_91 landowned_91  ///
	schooldmean91 urban91  lndvalpc91   d91_1 d91_3 d91_4 d91_5 d91_6

*COLUMN-1: SELECTION INTO MIGRATION
	*coeff:
	probit moved1 $CHAR91A  , robust
 	fitstat
	*Mfx:
	estpost margins, dydx(*)
 
*COLUMN-2: SELECTION INTO RETURN MIGRATION
preserve
	drop if rmigrant<0
	tab rmigrant,m
	sum $CHAR91A
	*coeff:
	probit rmigrant $CHAR91A  , robust
 	fitstat
	*Mfx:
	estpost margins, dydx(*)
 restore
	

********************************************************************************************************************************************************
*Table 7: estimating determinants of return migration in 2004-2010
********************************************************************************************************************************************************

*drop stayers:
drop if rmigrant<0

*COLUMN-1: POOLED
	*coeff:
	probit rmigrant male  $CONTROLS, robust
 	fitstat
	*Mfx:
	estpost margins, dydx(*)
 	di _b[lnconspc04]/(2*_b[lnconspc04_sq])*-1
	test _b[primary04]=_b[secondary04]
	 
*COLUMN-2: MEN
	*coeff:
	probit rmigrant   $CONTROLS   if male==1, robust 
	test _b[primary04]=_b[secondary04]
 	fitstat
	*Mfx:
	estpost margins, dydx(*)
 
*COLUMN-3:WOMEN
	*coeff:
	probit rmigrant   $CONTROLS    if male==0, robust
 	fitstat
	*Mfx:
	estpost margins, dydx(*)
 	di _b[lnconspc04]/(2*_b[lnconspc04_sq])*-1
	test _b[primary04]=_b[secondary04]

	*other models (not reported in the paper):
	
	*Test asset accumulation hypothesis:

	*replace the consumption variable with this + drop land:
	global CONTROLSA    years04 miglength04   primary04 secondary04 ///
	uempl04    farmw04  casual04 parent  married04 divwid04 ///
	 nathomeYN   lndvalpc04   hhsize child  loc_2 loc_3 loc_4 ///
	inhlandYN shock0409  BLshock0409   getsmarr unmarries ///
	d91_1 d91_3 d91_4 d91_5 d91_6  

	*COLUMN-1: POOLED without consumption
	probit rmigrant male  $CONTROLSA, robust
  
	*COLUMN-2: POOLED with consumption
	probit rmigrant male  $CONTROLSA lnconspc04  lnconspc04_sq  conspc04mis  , robust
 	 
*marginal effects of Column 1 of Table 9 using alternative probability models
 
	*make sure no stayers in the data:
	assert rmigrant>=0

	*COLUMN-1: PROBIT
		qui probit rmigrant male  $CONTROLS, robust
		estpost margins, dydx(*)
	*COLUMN-2: LOGIT
		qui logit rmigrant male  $CONTROLS, robust
		estpost margins, dydx(*)
	*COLUMN-3: CLOG-LOG
		qui cloglog rmigrant male  $CONTROLS, robust
		estpost margins, dydx(*)
	*COLUMN-4: LPM
		reg rmigrant male  $CONTROLS, robust
  
 
********************************************************************************************************************************************************
*Figure 2:
********************************************************************************************************************************************************

	sum lnconspc04, det
	label var lnconspc04 "logged per capita consumption"
	local r25=r(p25)
	local r75=r(p75) 

	global CONTROLSfig2    years04 miglength04   primary04 secondary04 ///
	uempl04    farmw04  casual04 parent  married04 divwid04 ///
	nathomeYN landowned04  conspc04mis hhsize  child  loc_2 loc_3 loc_4 ///
	inhlandYN shock0409  BLshock0409   getsmarr unmarries ///
	d91_1 d91_3 d91_4 d91_5 d91_6   

	probit rmigrant male c.lnconspc04 c.lnconspc04#c.lnconspc04   $CONTROLSfig2, robust
	quietly margins, at(lnconspc04=(12.25(0.25)14)) 

*Figure 2:
	marginsplot,  ylabel(0(0.05)0.3) scheme(s1mono) xline(`r25',lpattern(dash)) xline(`r75',lpattern(dash)) ///
	xtitle(, margin(medium)) ytitle("Pr (return migrant)", margin(medium))   title("")

 
********************************************************************************************************************************************************
*Table 8: Remittance analysis
********************************************************************************************************************************************************

	*additional controls:
	global addcontrols   hhsize_91  head_age_91 head_sex_91 lnconspc04_blv

	* PANEL A:
	 
	global rem  lnsen_blv  lnrec_blv
	desc $rem
	sum $rem


	 *COLUMN-1: POOLED
		qui probit rmigrant male $rem $addcontrols  $CONTROLS  , robust
		fitstat
		estpost margins, dydx(*)
 		
		
	*COLUMN-2: MEN
		qui probit rmigrant $rem $addcontrols   $CONTROLS   if male==1, robust
		fitstat
		estpost margins, dydx(*)
 		

	*COLUMN-3: WOMEN
		qui probit rmigrant $rem $addcontrols   $CONTROLS    if male==0, robust
		fitstat
		estpost margins, dydx(*)
 			

	* PANEL B:

	*use dummies, base category: net-remittances=0: 
	global rem  netreceiver netsender 
	desc $rem
	sum $rem

	*COLUMN-1: POOLED
		qui probit rmigrant male $rem $addcontrols  $CONTROLS  , robust
 		fitstat
		estpost margins, dydx(*)
 		test _b[netreceiver]=_b[netsender]
		
	*COLUMN-2: MEN
		qui probit rmigrant $rem $addcontrols   $CONTROLS   if male==1, robust
 		fitstat
		estpost margins, dydx(*)
 		test _b[netreceiver]=_b[netsender]

	*COLUMN-3: WOMEN
		qui probit rmigrant $rem $addcontrols   $CONTROLS    if male==0, robust
 		fitstat
		estpost margins, dydx(*)
 		test _b[netreceiver]=_b[netsender]


	* PANEL C:

	*break the sending/receiving into 2 dummies: 
	global rem  sen_blv_1 sen_blv_2 rec_blv_1 rec_blv_2
	desc $rem
	sum $rem

	 *COLUMN-1: POOLED
		qui probit rmigrant male $rem $addcontrols  $CONTROLS  , robust
		fitstat
		estpost margins, dydx(*)
 		test _b[sen_blv_1]=_b[sen_blv_2] 	
		test _b[rec_blv_1]=_b[rec_blv_2] 	

		
	*COLUMN-2: MEN
		qui probit rmigrant $rem $addcontrols   $CONTROLS   if male==1, robust
		fitstat
		estpost margins, dydx(*)
 		test _b[sen_blv_1]=_b[sen_blv_2] 	
		test _b[rec_blv_1]=_b[rec_blv_2] 


	*COLUMN-3: WOMEN
		qui probit rmigrant $rem $addcontrols   $CONTROLS    if male==0, robust
		fitstat
		estpost margins, dydx(*)
 		test _b[sen_blv_1]=_b[sen_blv_2] 	
		test _b[rec_blv_1]=_b[rec_blv_2] 
		

log close

